@@ -742,7 +742,10 @@ int
 sayHello(int fd, ioTunnel *en)
 {
 
-	char            helloStr[64];
+	char_buf_t *context;
+	char           *helloStr;
+	char            *patch;
+	char            *i;
 	revision        rev;
 	int             pid;
 	int             uid;
@@ -759,13 +762,28 @@ sayHello(int fd, ioTunnel *en)
 	gid = (int)getgid();
 #endif
 
-    getRevision(&rev);
-	helloStr[0] = '\0';
-	sprintf(helloStr, "0 0 client hello 0 0 %d %d -uid=%d -pid=%d -gid=%d\n", rev.Maj, rev.Min, uid, pid, gid);
+	context = dc_char_buf_create();
+	getRevision(&rev);
+	patch = strdup(rev.Patch);
+	while (i = strchr(patch, '\"')) {
+	  *i = '\'';
+	}
+
+	helloStr = dc_char_buf_sprintf(context, "0 0 client hello 0 0 %d %d %d \"%s\" -uid=%d -pid=%d -gid=%d\n", rev.Maj, rev.Min, rev.Bug, patch, uid, pid, gid);
+	free(patch);
+	freeRevision(&rev);
+
+	if (helloStr == NULL) {
+		dc_debug(DC_ERROR, "Failed to allocate memory");
+		dc_char_buf_free(context);
+		errno = EIO;
+		return -1;
+	}
 
 	if (sendControlMessage(fd, helloStr, strlen(helloStr), en) < 0) {
 		dc_debug(DC_ERROR, "Failed to send Hello fd=%d", fd);
 		errno = EIO;
+		dc_char_buf_free(context);
 		return -1;
 	}
 	pollAdd(fd);
@@ -773,11 +791,13 @@ sayHello(int fd, ioTunnel *en)
 	aM = getControlMessage(HAVETO, NULL);
 	if( aM == NULL ) {
 		pollDelete(fd);
+		dc_char_buf_free(context);
 		errno = EIO;
 		return -1;
 	}
 
 	/* FIXME: implement result recognition */
+	dc_char_buf_free(context);
 	free(aM);
 
 	return 0;
@@ -813,7 +833,7 @@ create_data_socket(int *dataFd, unsigned short *cbPort)
 #else
 	size_t          addrSize;
 #endif
-	int             bindResult;
+	int             bindResult = -1;
 	int             i;
 
 	*dataFd = socket(AF_INET, SOCK_STREAM, 0);
@@ -833,14 +853,12 @@ create_data_socket(int *dataFd, unsigned short *cbPort)
 
 
 	/* try to get free slot in range of TCP ports */
-	for( i = 0 ; i < callBackPortRange; i++) {
+	for( i = 0 ; i < callBackPortRange && bindResult < 0; i++) {
 
 		*cbPort += i;
 		me.sin_port = htons(*cbPort + i);
 		addrSize = sizeof(me);
 		bindResult = bind(*dataFd, (struct sockaddr *) & me, addrSize);
-		if( bindResult == 0) break;
-
 	}
 
 	if (bindResult < 0) {
@@ -889,7 +907,7 @@ ascii_open_conversation(struct vsp_node * node)
 	outStr = dc_char_buf_sprintf(context,"%d 0 client %s \"%s\"", node->queueID,
 	                                          asciiCommand(node->asciiCommand),
 	                                          node->asciiCommand == DCAP_CMD_TRUNC ? node->ipc : node->pnfsId );
-	
+
 	if (outStr == NULL){
 		goto out_of_mem_exit;
 	}
@@ -1274,7 +1292,6 @@ data_hello_conversation(struct vsp_node * node)
 	u_short         remotePort;
 	char           *hostname;
 	int32_t         sessionId, challengeSize;
-	int             tmp;
 
 	while(1) {
 
@@ -1360,10 +1377,10 @@ data_hello_conversation(struct vsp_node * node)
 		}
 #endif /* SO_SNDBUF */
 
-		tmp = readn(newFd, (char *) &sessionId, sizeof(sessionId), NULL);
+		readn(newFd, (char *) &sessionId, sizeof(sessionId), NULL);
 		sessionId = ntohl(sessionId);
 
-		tmp = readn(newFd, (char *) &challengeSize, sizeof(challengeSize), NULL);
+		readn(newFd, (char *) &challengeSize, sizeof(challengeSize), NULL);
 		challengeSize = ntohl(challengeSize);
 
 		dc_debug(DC_INFO, "Got callback connection from %s:%d for session %d, myID %d.",
@@ -1417,7 +1434,6 @@ int sendDataMessage(struct vsp_node *node, char *message, int sizeOfMessage, int
 	asciiMessage *aM;
 	int try = 0;
 	int rc = 0;
-	int err = 0;
 
 	dc_debug(DC_CALLS, "Entered sendDataMessage.");
 again:
@@ -1436,7 +1452,6 @@ again:
 	if( ret < sizeOfMessage ) {
 		dc_debug(DC_ERROR, "sendDataMessage: write message failed => ret = %d.", ret);
 		rc = -1;
-		err = 1;
 		goto end;
 	}
 
@@ -1641,10 +1656,8 @@ void dc_setReplyHostName(const char *s)
    if( (s == NULL) || (getenv("DCACHE_REPLY") != NULL) )
         return;
 
-   if( hostName != NULL )
-        free(hostName);
-
-	dc_debug(DC_INFO, "Binding client callback hostname to %s.", s);
+    dc_debug(DC_INFO, "Binding client callback hostname to %s.", s);
+    free(hostName);
     hostName = (char *)strdup(s);
 }
 
@@ -1941,9 +1954,15 @@ void getRevision( revision *rev )
 {
 	rev->Maj = dc_getProtocol();
 	rev->Min = dc_getMajor();
+	rev->Bug = dc_getMinor();
+	rev->Patch = strdup(dc_getPatch());
 }
 
 
+void freeRevision( revision *rev )
+{
+	free(rev->Patch);
+}
 
 void dc_setTCPSendBuffer( int newSize )
 {
@@ -2034,9 +2053,11 @@ server * url2srv(dcap_url *url)
     srv->hostname = strdup(url->host);
     srv->port = url->port;
 
-    if (url->prefix != NULL) {
-        tunnel = malloc(64);
-        tunnel[0] = '\0';
+    tunnel = getenv("DCACHE_IO_TUNNEL");
+    if (tunnel != NULL) {
+        srv->tunnel = addIoPlugin(tunnel);
+    } else if (url->prefix != NULL) {
+        tunnel = malloc(strlen(url->prefix) + 12 + 1); // len(prefix) + len(libTunnel.so) + '\0'
         sprintf(tunnel, "lib%sTunnel.so", url->prefix);
         srv->tunnel = addIoPlugin(tunnel);
         free(tunnel);
