@@ -9,8 +9,8 @@
  *   See the file COPYING.LIB
  *
  */
- 
- 
+
+
 /*
  * $Id: dcap_debug.h,v 1.12 2004-11-01 19:33:29 tigran Exp $
  */
@@ -18,13 +18,14 @@
 #ifndef _DCAP_DEBUG_H_
 #define _DCAP_DEBUG_H_
 
+#include <stdarg.h>
+
 #include "debug_level.h"
 
-extern void dc_debug(unsigned int, const char *, ...);
-extern void dc_setDebugLevel(unsigned int);
-extern void dc_setStrDebugLevel(const char *);
-extern void dc_setRecoveryDebugLevel();
-extern void init_dc_debug();
+#define MAX_MESSAGE_LEN 2048
 
+extern void dc_setRecoveryDebugLevel();
+void dc_vdebug(unsigned int level, const char *format, va_list ap);
+int dc_is_debug_level_enabled( unsigned int level);
 
 #endif				/* _DCAP_DEBUG_H_ */
