@@ -9,8 +9,8 @@
  *   See the file COPYING.LIB
  *
  */
- 
- 
+
+
 /*
  * $Id: ioTunnel.h,v 1.4 2004-11-01 19:33:30 tigran Exp $
  */
@@ -21,7 +21,7 @@
 #ifndef WIN32
 #   include <unistd.h>
 #else
-#   include "dcap_win32.h"
+#   include "dcap_unix2win.h"
 #endif
 
 typedef struct {
